@@ -1168,4 +1168,8 @@ class EDM_EGLINTENSITY_TYPE(Enum):
     EDM_EGLINTEN_OFF = 0
     EDM_EGLINTEN_LOW = 1
     EDM_EGLINTEN_MID = 2
-    EDM_EGLINTEN_HIGH = 3
\ No newline at end of file
+    EDM_EGLINTEN_HIGH = 3
+
+class WIR_RECFORMAT(Enum):
+    WIR_RECFORMAT_GSI = 0 # defines recording format is GSI (standard)
+    WIR_RECFORMAT_GSI16 = 1 # defines recording format is the new GSI-16
\ No newline at end of file
